@@ -1,13 +1,13 @@
 ;;; debian-control-mode.el --- major mode for Debian control files
 
 ;; Copyright (C) 2001, 2003 Free Software Foundation, Inc.
-;; Copyright (C) 2003, 2004, 2005 Peter S Galbraith <psg@debian.org>
+;; Copyright (C) 2003-2005, 2007-2011 Peter S Galbraith <psg@debian.org>
 
 ;; Author: Colin Walters <walters@debian.org>
 ;; Maintainer: Peter S Galbraith <psg@debian.org>
 ;; Created: 29 Nov 2001
-;; Version: 1.3
-;; X-RCS: $Id: debian-control-mode.el,v 1.16 2011-06-25 18:03:10 psg Exp $
+;; Version: 1.5
+;; X-RCS: $Id: debian-control-mode.el,v 1.17 2011-08-17 02:59:50 psg Exp $
 ;; Keywords: convenience
 
 ;; This file is free software; you can redistribute it and/or modify
@@ -32,6 +32,8 @@
 
 ;;; Change Log:
 
+;; V1.5 (2011-08-16) Added "Multi-Arch:" (Closes #634162)
+
 ;; V1.4 (2011-06-24) Added "XS-Python-Version" to debian-control-source-fields
 ;;  (Closes #591697)
 
@@ -217,15 +219,9 @@
 		'(symbol-value debian-control-source-package-face)
 	      '(list 'face debian-control-source-package-face))
 	   nil nil))
-    (,(concat "^\\(Package:\\)\\s-*"
-	      debian-control-package-name-regexp
-	      "\\s-*$")
+    ("^\\(Multi-Arch:\\)\\s-*\\(same\\|foreign\\|allowed\\)"
      (1 font-lock-function-name-face)
-     ,(list 2
-	    (if (featurep 'xemacs)
-		'(symbol-value 'debian-control-binary-package-face)
-	      '(list 'face debian-control-binary-package-face))
-	    nil nil))
+     (2 font-lock-keyword-face))
     (,debian-control-source-fields-regexp
      (1 font-lock-keyword-face))
     (,debian-control-binary-fields-regexp
