@@ -20,9 +20,9 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING.
+;; If not, write to the Free Software Foundation, 675 Mass Ave,
+;; Cambridge, MA 02139, USA.
 
 ;; ----------------------------------------------------------------------------
 ;;; Commentary:
@@ -251,7 +251,7 @@ The directories can be:
   - a symbol object evaluating to a list of strings (e.g. `load-path')
 
 You may mix environment variables and directory paths together.
-You may add trailing directoty paths to environment variables, e.g. $HOME/bin
+You may add trailing directory paths to environment variables, e.g. $HOME/bin
 You may not mix strings with elisp lists (like `load-path').
 You may terminate a directory name with double slashes // indicating that
  all subdirectories beneath it should also be searched.")
